/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.common.test;

import org.springframework.boot.test.util.TestPropertyValues;
import org.springframework.context.ApplicationContextInitializer;
import org.springframework.context.ConfigurableApplicationContext;
import org.testcontainers.containers.MongoDBContainer;
import org.testcontainers.utility.DockerImageName;

import lombok.extern.log4j.Log4j2;

@Log4j2
public class DbInitializer implements ApplicationContextInitializer<ConfigurableApplicationContext> {

	private static MongoDBContainer dbContainer;

	@Override
	public void initialize(ConfigurableApplicationContext applicationContext) {
		initDb();

		var host = dbContainer.getHost();
		var port = dbContainer.getFirstMappedPort().toString();

		LOG.info("Init DB: {}:{} ", host, port);

		TestPropertyValues.of(
				"spring.data.mongodb.host=" + host,
				"spring.data.mongodb.port=" + port)
				.applyTo(applicationContext.getEnvironment());
	}

	static void initDb() {
		if (dbContainer == null) {
			LOG.info("Creating mongoDB ...");
			dbContainer = new MongoDBContainer(DockerImageName.parse("mongo").withTag("4.4"));
		}
		if (!dbContainer.isRunning()) {
			LOG.info("... starting mongoDB ...");
			dbContainer.start();

//			System.setProperty("mongodb.host", dbContainer.getHost());
//			System.setProperty("mongodb.port", dbContainer.getFirstMappedPort().toString());
//			LOG.info("on Port " + dbContainer.getFirstMappedPort().toString());

		}
	}

}
